#!/bin/sh

# Build script for Mumble
# Author: Ejis <ejis@mailoo.org>

# Homepage: http://mumble.sourceforge.net/


set -e


SOFTNAME=mumble
VERSION=1.2.3
ZENVER=70
BUILD=1

CATEGORY=extra/n

MARCH=i486
FLAGS="-O2 -march=$MARCH -mtune=i686"

DOTNEW=1

CWD=$(pwd)

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

SOFTDIR=$CWD/$SOFTNAME-$VERSION
PKGDIR=$CWD/$PKG

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep

SRCFILES=(
	$SOFTNAME-$VERSION.tar.gz
	$SOFTNAME.patch
	$SOFTNAME.png
)

HOSTURL=http://zenwalk.pinguix.com/user-accounts/ejis/$CATEGORY/$SOFTNAME/$ZENVER
SRCURLS=(
	http://downloads.sourceforge.net/sourceforge/mumble
	$HOSTURL
)

SRCLINKS=(
	${SRCURLS[0]}/${SRCFILES[0]}
	${SRCURLS[1]}/${SRCFILES[1]}
	${SRCURLS[1]}/${SRCFILES[2]}
)

DOC=(
	$SOFTDIR/CHANGES
	$SOFTDIR/INSTALL
	$SOFTDIR/LICENSE
	$SOFTDIR/README
	$SOFTDIR/README.Linux
)

EXTRADEPS=(
)

LESSDEPS=(
	x11-driver-nvidia
	x11-driver-nvidia-rt
)


# Check for source files and download them if necessary

if [ ! -f ${SRCFILES[0]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[0]}
fi

if [ ! -f ${SRCFILES[1]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[1]}
fi

if [ ! -f ${SRCFILES[2]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[2]}
fi


# Erase the previous build files

rm -rf $SOFTDIR $PKGFILE $PKGDIR $MD5 $SRC $DEP
mkdir -p $PKG


# Build

echo ""
echo "-----Building-----"
echo ""

tar -xvf $CWD/${SRCFILES[0]}

cd $SOFTDIR

export CFLAGS=$FLAGS
export CXXFLAGS=$FLAGS

patch -p1 < $CWD/${SRCFILES[1]}

qmake main.pro CONFIG+=no-oss \
	CONFIG+=no-pulseaudio CONFIG+=no-embed-qt-translations \
	-recursive

export CPLUS_INCLUDE_PATH=$CPLUS_INCLUDE_PATH:/usr/lib/Ice-3.3.1/include
make -j2 release


mkdir -p $PKGDIR/usr/bin
mkdir $PKGDIR/usr/lib
mkdir -p $PKGDIR/usr/man/man1
mkdir -p $PKGDIR/usr/share/icons/hicolor/48x48/apps
mkdir -p $PKGDIR/usr/share/applications

mv -v $SOFTDIR/release/mumble $PKGDIR/usr/bin/
mv -v $SOFTDIR/release/mumble11x $PKGDIR/usr/bin/
mv -v $SOFTDIR/release/murmurd $PKGDIR/usr/bin/

mv -v $SOFTDIR/release/lib* $PKGDIR/usr/lib/
mv -v $SOFTDIR/release/plugins/lib* $PKGDIR/usr/lib/

cd ./man
	gzip ./*
cd ../
mv -v ./man/*.gz $PKGDIR/usr/man/man1/

cp -v $CWD/${SRCFILES[2]} \
	$PKGDIR/usr/share/icons/hicolor/48x48/apps/

cat << EOF > $PKGDIR/usr/share/applications/mumble.desktop
[Desktop Entry]
Encoding=UTF-8
Type=Application
Name=Mumble
Comment=Voice chat software
Exec=mumble
Icon=mumble
X-MultipleArgs=false
Terminal=false
Categories=Network
EOF


# Packaging

echo ""
echo "-----Packaging-----"
echo ""

cd $PKGDIR

mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION
mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION


	   #|-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc <<EOF
$SOFTNAME: $SOFTNAME
$SOFTNAME:
$SOFTNAME: Low-latency, high-quality voice communication for gamers. Includes
$SOFTNAME: game linking, so voice from other players comes from the direction of
$SOFTNAME: their characters, and has echo cancellation so the sound from your
$SOFTNAME: loudspeakers won't be audible to other players.
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME:
EOF

	
# Redundent

if [ -d $PKGDIR/usr/share/doc ]; then
	mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
	rm -rvf $PKGDIR/usr/share/doc
fi

if [ -d $PKGDIR/etc ]; then
	if [ $DOTNEW == 1 ]; then
		dotnewfiles=$(find $PKGDIR/etc -type f -print -exec \
			mv {} {}.new \;)
		cat << EOF > $PKGDIR/install/doinst.sh
dotnewfiles=(${dotnewfiles[@]})

for file in \${dotnewfiles[@]}; do
	if [ ! -f \$file ]; then
		mv \$file.new \$file
	fi
done
EOF
		sed -i "s:$PKGDIR/::g" $PKGDIR/install/doinst.sh
	fi
fi

find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true

if [ -d $PKGDIR/usr/man ]; then
	
	( cd $PKGDIR/usr/man
		find . -type f -exec gzip -9 {} \;
		for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
	)
	
fi

if [ -d $PKGDIR/usr/info ]; then
	
	rm -f $PKGDIR/usr/info/dir
	gzip -9 $PKGDIR/usr/info/*.info*
	
fi

find . -name perllocal.pod \
	-o -name ".packlist" \
	-o -name "*.bs" \
	| xargs rm -f


cp -v $CWD/build-$SOFTNAME.sh \
	$PKGDIR/usr/src/$SOFTNAME-$VERSION/

cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


# fix permissions
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;


fakeroot /sbin/makepkg -l y -c n $PKGFILE


cd $CWD

echo 'Creating .md5 file'
md5sum $PKG.txz > $MD5

echo 'Creating .src file'
echo "$HOSTURL/build-$SOFTNAME.sh" > $SRC
for link in ${SRCLINKS[@]}; do
	echo $link >> $SRC
done

echo 'Checking for dependencies'
deps=$(depfinder $PKGFILE)

for dep in ${EXTRADEPS[@]}; do
	deps="$deps,$dep"
done

for dep in ${LESSDEPS[@]}; do
	deps=${deps/$dep/}
done

order=$(echo ${deps//,/ } | sort -d)
echo ${order// /,} > $DEP

echo "Removing build directories"
rm -rf $SOFTDIR $PKGDIR
